/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 09043
 |          POLICY RESEARCH ON AGING AND MENTAL HEALTH SERVICES
 |                            (PRAMHS) PROJECT
 |                  (DATASET 0003: STATE UNITS ON AGING)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE caseid    1='(1) Unique identification code'
                  33='(33) Unique identification code' ;
  VALUE v5ffffff  1='(1) Alabama' 2='(2) Alaska' 3='(3) Arizona' 4='(4) Arkansas'
                  5='(5) California' 6='(6) Colorado' 7='(7) Connecticut' 8='(8) Delaware'
                  9='(9) District of Columbia' 10='(10) Florida' 11='(11) Georgia'
                  12='(12) Hawaii' 13='(13) Idaho' 14='(14) Illinois' 15='(15) Indiana' 16='(16) Iowa'
                  17='(17) Kansas' 18='(18) Kentucky' 19='(19) Louisiana' 20='(20) Maine'
                  21='(21) Maryland' 22='(22) Massachusetts' 23='(23) Michigan'
                  24='(24) Minnesota' 25='(25) Mississippi' 26='(26) Missouri' 27='(27) Montana'
                  28='(28) Nebraska' 29='(29) Nevada' 30='(30) New Hampshire'
                  31='(31) New Jersey' 32='(32) New Mexico' 33='(33) New York'
                  34='(34) North Carolina' 35='(35) North Dakota' 36='(36) Ohio'
                  37='(37) Oklahoma' 38='(38) Oregon' 39='(39) Pennsylvania'
                  40='(40) Rhode Island' 41='(41) South Carolina' 42='(42) South Dakota'
                  43='(43) Tennessee' 44='(44) Texas' 45='(45) Utah' 46='(46) Vermont'
                  47='(47) Virginia' 48='(48) Washington' 49='(49) West Virginia'
                  50='(50) Wisconsin' 51='(51) Wyoming' 52='(52) American Samoa' 53='(53) Guam'
                  54='(54) Puerto Rico' 55='(55) Virgin Islands' 56='(56) Marianna Islands'
                  57='(57) North Marianna Islands' ;
  VALUE v6ffffff  1='(1) Area agency on aging' 2='(2) State unit on aging'
                  3='(3) Community mental health center'
                  4='(4) State mental health agency' ;
  VALUE v7ffffff  1='(1) Agency code' 56='(56) Agency code' ;
  VALUE v8ffffff  1='(1) One year' 26='(26) Twenty six years' ;
  VALUE v9ffffff  400='(400) Thousand dollars' 77000='(77000) Thousand dollars' ;
  VALUE v10fffff  0='(0) None' 52000='(52000) Thousand dollars' 99999='(99999) N/A' ;
  VALUE v11fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v12fffff  4='(4) Number of professional staff employed a'
                  401='(401) Number of professional staff employed a' 999='(999) N/A' ;
  VALUE v13fffff  1='(1) Number of support staff employed at SUA'
                  263='(263) Number of support staff employed at SUA' ;
  VALUE v14fffff  2='(2) Percentage of prof staff holding master'
                  90='(90) Percentage of prof staff holding master' 99='(99) N/A' ;
  VALUE v15fffff  3='(3) Percentage prof staff with one year''s e'
                  99='(99) Percentage prof staff with one year''s e' 999='(999) N/A' ;
  VALUE v16fffff  2='(2) Average years experience in elderly ser'
                  10='(10) Average years experience in elderly ser' 99='(99) N/A' ;
  VALUE v17fffff  5='(5) Percentage prof staff participating in'
                  99='(99) Percentage prof staff participating in' 999='(999) N/A' ;
  VALUE v18fffff  1='(1) Monthly or less' 2='(2) Weekly' 3='(3) Daily' ;
  VALUE v19fffff  1='(1) Interagency committee' 2='(2) Letter of cooperation'
                  3='(3) No formal provision' 4='(4) Other' 9='(9) N/A' ;
  VALUE v20fffff  1='(1) No contact' 2='(2) Less often' 3='(3) Monthly' 4='(4) Weekly' ;
  VALUE v21fffff  1='(1) Not at all' 2='(2) Adequate' 3='(3) Well' ;
  VALUE v22fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v23fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v24fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v25fffff  1='(1) No involvement' 2='(2) Information provision'
                  3='(3) Review and comment' 4='(4) Joint planning session' ;
  VALUE v26fffff  1='(1) No involvement' 2='(2) Information provision'
                  3='(3) Review and comment' 4='(4) Joint planning session' 9='(9) N/A' ;
  VALUE v27fffff  1='(1) No involvement' 2='(2) Information provision'
                  3='(3) Review and comment' 4='(4) Joint planning session' 9='(9) N/A' ;
  VALUE v28fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v29fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v30fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v31fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v32fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v33fffff  1='(1) Highest priority' 6='(6) Lowest priority' 9='(9) N/A' ;
  VALUE v34fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v35fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v36fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v37fffff  1='(1) Not at all' 2='(2) Limited' 3='(3) Moderately' 4='(4) Greatly'
                  9='(9) N/A' ;
  VALUE v38fffff  1='(1) Yes' 2='(2) No' 9='(9) N/A' ;
  VALUE v39fffff  1='(1) Not at all' 2='(2) Moderately responsive'
                  3='(3) Very responsive' 9='(9) N/A' ;
  VALUE v40fffff  1='(1) Yes' 9='(9) N/A' ;
  VALUE v41fffff  2='(2) Yes' 9='(9) N/A' ;
  VALUE v42fffff  3='(3) Yes' 9='(9) N/A' ;
  VALUE v43fffff  4='(4) Yes' 9='(9) N/A' ;
  VALUE v44fffff  5='(5) Yes' 9='(9) N/A' ;
  VALUE v45fffff  6='(6) Yes' 9='(9) N/A' ;
  VALUE v46fffff  7='(7) Yes' 9='(9) N/A' ;
  VALUE v47fffff  1='(1) Yes' 9='(9) N/A' ;
  VALUE v48fffff  2='(2) Yes' 9='(9) N/A' ;
  VALUE v49fffff  3='(3) Yes' 9='(9) N/A' ;
  VALUE v50fffff  4='(4) Yes' 9='(9) N/A' ;
  VALUE v51fffff  1='(1) Positive' 2='(2) Negative' ;
  VALUE v52fffff  1='(1) Informal, personal relations familiarit'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v53fffff  1='(1) Informal, personal relations familiarit'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v54fffff  1='(1) Informal, personal relations familiarit'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v55fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v56fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v57fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v58fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v59fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v60fffff  1='(1) Medical Model vs. Social Service Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v61fffff  1='(1) Communications (contact) no routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency-reorganization'
                  5='(5) Proximity, co-location' 6='(6) Other (agency closed CMHC)'
                  9='(9) N/A' ;
  VALUE v62fffff  1='(1) Communications (contact) no routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency-reorganization'
                  5='(5) Proximity, co-location' 6='(6) Other (agency closed CMHC)'
                  9='(9) N/A' ;
  VALUE v63fffff  1='(1) Communications (contact) no routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency-reorganization'
                  5='(5) Proximity, co-location' 6='(6) Other (agency closed CMHC)'
                  9='(9) N/A' ;
  VALUE v64fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in ME prog' 9='(9) N/A' ;
  VALUE v65fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in ME prog' 9='(9) N/A' ;
  VALUE v66fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest in ME prog' 9='(9) N/A' ;
  VALUE v67fffff  1='(1) Incongruent by 2' 2='(2) Incongruent by 1'
                  3='(3) Both answered no formal provision'
                  4='(4) Both answered letter of cooperation'
                  5='(5) Both answered interagency agreement' 9='(9) N/A' ;
  VALUE v68fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no contact'
                  5='(5) Both answered less often' 6='(6) Both answered monthly'
                  7='(7) Both answered weekly' 9='(9) N/A' ;
  VALUE v69fffff  1='(1) Incongruent by 2' 2='(2) Incongruent by 1'
                  3='(3) Both answered not at all' 4='(4) Both answered adequately'
                  5='(5) Both answered well' 9='(9) N/A' ;
  VALUE v70fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v71fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v72fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v73fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered not at all'
                  5='(5) Both answered limited' 6='(6) Both answered moderate'
                  7='(7) Both answered great' 9='(9) N/A' ;
  VALUE v74fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v75fffff  1='(1) Incongruent by 2' 2='(2) Incongruent by 1'
                  3='(3) Both answered not at all' 4='(4) Both answered moderately'
                  5='(5) Both answered very' 9='(9) N/A' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V10 = 99999) THEN V10 = .;
   IF (V11 = 9) THEN V11 = .;
   IF (V12 = 999) THEN V12 = .;
   IF (V14 = 99) THEN V14 = .;
   IF (V15 = 999) THEN V15 = .;
   IF (V16 = 99) THEN V16 = .;
   IF (V17 = 999) THEN V17 = .;
   IF (V19 = 9) THEN V19 = .;
   IF (V23 = 9) THEN V23 = .;
   IF (V24 = 9) THEN V24 = .;
   IF (V26 = 9) THEN V26 = .;
   IF (V27 = 9) THEN V27 = .;
   IF (V28 = 9) THEN V28 = .;
   IF (V29 = 9) THEN V29 = .;
   IF (V30 = 9) THEN V30 = .;
   IF (V31 = 9) THEN V31 = .;
   IF (V32 = 9) THEN V32 = .;
   IF (V33 = 9) THEN V33 = .;
   IF (V34 = 9) THEN V34 = .;
   IF (V35 = 9) THEN V35 = .;
   IF (V37 = 9) THEN V37 = .;
   IF (V38 = 9) THEN V38 = .;
   IF (V39 = 9) THEN V39 = .;
   IF (V40 = 9) THEN V40 = .;
   IF (V41 = 9) THEN V41 = .;
   IF (V42 = 9) THEN V42 = .;
   IF (V43 = 9) THEN V43 = .;
   IF (V44 = 9) THEN V44 = .;
   IF (V45 = 9) THEN V45 = .;
   IF (V46 = 9) THEN V46 = .;
   IF (V47 = 9) THEN V47 = .;
   IF (V48 = 9) THEN V48 = .;
   IF (V49 = 9) THEN V49 = .;
   IF (V50 = 9) THEN V50 = .;
   IF (V52 = 9) THEN V52 = .;
   IF (V53 = 9) THEN V53 = .;
   IF (V54 = 9) THEN V54 = .;
   IF (V55 = 9) THEN V55 = .;
   IF (V56 = 9) THEN V56 = .;
   IF (V57 = 9) THEN V57 = .;
   IF (V58 = 9) THEN V58 = .;
   IF (V59 = 9) THEN V59 = .;
   IF (V60 = 9) THEN V60 = .;
   IF (V61 = 9) THEN V61 = .;
   IF (V62 = 9) THEN V62 = .;
   IF (V63 = 9) THEN V63 = .;
   IF (V64 = 9) THEN V64 = .;
   IF (V65 = 9) THEN V65 = .;
   IF (V66 = 9) THEN V66 = .;
   IF (V67 = 9) THEN V67 = .;
   IF (V68 = 9) THEN V68 = .;
   IF (V69 = 9) THEN V69 = .;
   IF (V70 = 9) THEN V70 = .;
   IF (V71 = 9) THEN V71 = .;
   IF (V72 = 9) THEN V72 = .;
   IF (V73 = 9) THEN V73 = .;
   IF (V74 = 9) THEN V74 = .;
   IF (V75 = 9) THEN V75 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CASEID caseid. V5 v5ffffff. V6 v6ffffff.
         V7 v7ffffff. V8 v8ffffff. V9 v9ffffff.
         V10 v10fffff. V11 v11fffff. V12 v12fffff.
         V13 v13fffff. V14 v14fffff. V15 v15fffff.
         V16 v16fffff. V17 v17fffff. V18 v18fffff.
         V19 v19fffff. V20 v20fffff. V21 v21fffff.
         V22 v22fffff. V23 v23fffff. V24 v24fffff.
         V25 v25fffff. V26 v26fffff. V27 v27fffff.
         V28 v28fffff. V29 v29fffff. V30 v30fffff.
         V31 v31fffff. V32 v32fffff. V33 v33fffff.
         V34 v34fffff. V35 v35fffff. V36 v36fffff.
         V37 v37fffff. V38 v38fffff. V39 v39fffff.
         V40 v40fffff. V41 v41fffff. V42 v42fffff.
         V43 v43fffff. V44 v44fffff. V45 v45fffff.
         V46 v46fffff. V47 v47fffff. V48 v48fffff.
         V49 v49fffff. V50 v50fffff. V51 v51fffff.
         V52 v52fffff. V53 v53fffff. V54 v54fffff.
         V55 v55fffff. V56 v56fffff. V57 v57fffff.
         V58 v58fffff. V59 v59fffff. V60 v60fffff.
         V61 v61fffff. V62 v62fffff. V63 v63fffff.
         V64 v64fffff. V65 v65fffff. V66 v66fffff.
         V67 v67fffff. V68 v68fffff. V69 v69fffff.
         V70 v70fffff. V71 v71fffff. V72 v72fffff.
         V73 v73fffff. V74 v74fffff. V75 v75fffff.
          ;

RUN ;
